#!/bin/bash -xv

# the script creates check plots of the PSF
# anisotropy for the MEGAPRIME geometry.
#
# The case where CCDS have the 'BADMODE' flag
# is not yet implemented.

# 01.08.2007:
# some cleaning of not needed temporary files added

# $1: main directory
# $2: science dir.
# $3: image extension (ext) on ..._iext.fits (i is the chip number)

. MEGAPRIME.ini 

if [ ! -d "/$1/$2/cat/PSFcheck" ]; then
  mkdir /$1/$2/cat/PSFcheck
fi

ls -1 /$1/$2/*_1$3.fits > psfimages_plot_$$

cat psfimages_plot_$$ |\
{
  while read file
  do
    BASE=`basename ${file} _1$3.fits`

    i=1
    
    if [ -f tmp_all.asc_$$ ]; then
	rm tmp_all.asc_$$ 
    fi

    while [ "${i}" -le ${NCHIPS} ]
    do
      ${P_LDACTOASC} -i /$1/$2/cat/${BASE}_${i}$3_ksb.cat2 -b -t OBJECTS\
                     -k Xpos Ypos e1 e2 > tmp_${i}.asc_plot_$$
      ${P_GAWK} '{print $3, $4}' tmp_${i}.asc_plot_$$ >> tmp_all.asc_$$ 
      i=$(( $i + 1 ))
    done

    # calculate min, max and mean and standard deviations of the ellipticities:
    {
      echo 'macro read "'${SMMACROS}'/shearfield.sm"'
      echo 'device "postportfile /'$1'/'$2'/cat/PSFcheck/'${BASE}''$3'.ps"'
      echo "relocate (17600 32500)"
      echo "putlabel 5 '${BASE}$3'"
      echo "limits 0 1990 0 4000"
      echo "lweight 1.5"
      echo "expand 0.5"

      echo "window -9 -4 1 1"
      echo "box"
      echo "shearfield tmp_1.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 2 1"
      echo "box 1 0"
      echo "shearfield tmp_2.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 3 1"
      echo "box 1 0"
      echo "shearfield tmp_3.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 4 1"
      echo "box 1 0"
      echo "shearfield tmp_4.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 5 1"
      echo "box 1 0"
      echo "shearfield tmp_5.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 6 1"
      echo "box 1 0"
      echo "shearfield tmp_6.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 7 1"
      echo "box 1 0"
      echo "shearfield tmp_7.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 8 1"
      echo "box 1 0"
      echo "shearfield tmp_8.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 9 1"
      echo "box 1 0"
      echo "shearfield tmp_9.asc_plot_$$ 2000"
      echo "expand 0.5"

      echo "window -9 -4 1 2"
      echo "box 0 2"
      echo "shearfield tmp_10.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 2 2"
      echo "box 0 0"
      echo "shearfield tmp_11.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 3 2"
      echo "box 0 0"
      echo "shearfield tmp_12.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 4 2"
      echo "box 0 0"
      echo "shearfield tmp_13.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 5 2"
      echo "box 0 0"
      echo "shearfield tmp_14.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 6 2"
      echo "box 0 0"
      echo "shearfield tmp_15.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 7 2"
      echo "box 0 0"
      echo "shearfield tmp_16.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 8 2"
      echo "box 0 0"
      echo "shearfield tmp_17.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 9 2"
      echo "box 0 0"
      echo "shearfield tmp_18.asc_plot_$$ 2000"
      echo "expand 0.5"

      echo "window -9 -4 1 3"
      echo "box 0 2"
      echo "shearfield tmp_19.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 2 3"
      echo "box 0 0"
      echo "shearfield tmp_20.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 3 3"
      echo "box 0 0"
      echo "shearfield tmp_21.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 4 3"
      echo "box 0 0"
      echo "shearfield tmp_22.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 5 3"
      echo "box 0 0"
      echo "shearfield tmp_23.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 6 3"
      echo "box 0 0"
      echo "shearfield tmp_24.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 7 3"
      echo "box 0 0"
      echo "shearfield tmp_25.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 8 3"
      echo "box 0 0"
      echo "shearfield tmp_26.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 9 3"
      echo "box 0 0"
      echo "shearfield tmp_27.asc_plot_$$ 2000"
      echo "expand 0.5"

      echo "window -9 -4 1 4"
      echo "box 0 2"
      echo "shearfield tmp_28.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 2 4"
      echo "box 0 0"
      echo "shearfield tmp_29.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 3 4"
      echo "box 0 0"
      echo "shearfield tmp_30.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 4 4"
      echo "box 0 0"
      echo "shearfield tmp_31.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 5 4"
      echo "box 0 0"
      echo "shearfield tmp_32.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 6 4"
      echo "box 0 0"
      echo "shearfield tmp_33.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 7 4"
      echo "box 0 0"
      echo "shearfield tmp_34.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 8 4"
      echo "box 0 0"
      echo "shearfield tmp_35.asc_plot_$$ 2000"
      echo "expand 0.5"
      echo "window -9 -4 9 4"
      echo "box 0 0"
      echo "shearfield tmp_36.asc_plot_$$ 2000"
      echo "expand 0.5"

      echo "data tmp_all.asc_$$"
      echo "read { e1 1 e2 2 }"
      echo "stats e1 m1 s1 k1"
      echo "stats e2 m2 s2 k2"
      echo "relocate ( 2000 1500 )"
      echo "define s (sprintf('<e1>: %.2f +/- ', \$m1))"
      echo 'label $s'
      echo "define s (sprintf('%.2f;', \$s1))"
      echo 'label $s'
      echo "relocate ( 8000 1500 ) "
      echo "define s (sprintf('<e2>: %.2f +/- ', \$m2))"
      echo 'label $s'
      echo "define s (sprintf('%.2f;', \$s2))"
      echo 'label $s'
      echo "set eabs=sqrt(e1*e1+e2*e2)"
      echo "sort {eabs}"
      echo "relocate ( 15000 1500 )"
      echo "define s (sprintf('|e| min = %.2f;', \$(eabs[0])))"
      echo 'label $s'
      echo "relocate ( 20000 1500 )"
      echo "define n (dimen(eabs)-1)"
      echo "define s (sprintf('|e| max = %.2f', \$(eabs[\$n])))"
      echo 'label $s'

      echo "sort {e1}"
      echo "relocate ( 2000 1000 )"
      echo "define s (sprintf('e1 min = %.2f;', \$(e1[0])))"
      echo 'label $s'
      echo "relocate ( 8000 1000 )"
      echo "define n (dimen(e1)-1)"
      echo "define s (sprintf('e1 max = %.2f', \$(e1[\$n])))"
      echo 'label $s'

      echo "sort {e2}"
      echo "relocate ( 15000 1000 )"
      echo "define s (sprintf('e2 min = %.2f;', \$(e2[0])))"
      echo 'label $s'
      echo "relocate ( 20000 1000 )"
      echo "define n (dimen(e2)-1)"
      echo "define s (sprintf('e2 max = %.2f', \$(e2[\$n])))"
      echo 'label $s'

      echo "expand 1.0"
      echo "hardcopy"
    } | ${P_SM:?}
  done
}

rm tmp_*.asc_plot_$$
rm tmp_all.asc_$$
rm psfimages_plot_$$
