#!/bin/bash

# script to create 'summary' files for processing CFHT data
# with the script 'proc_single_MEGAPRIME.sh'.
# The script further output a file containing field and
# filter combinations of the available data.

# $1: info file; this file contains three columns:
#     TARGET   image.fits    FILTER (r.MP9601 etc.)
# $2: SURVEY under consideration

INFOFILE=$1
SURVEY=$2

for FILT in i.MP9701 i.MP9702 r.MP9601 g.MP9401 u.MP9301 z.MP9801
do
  grep "${FILT}" ${INFOFILE} | awk '{print $1, $2}' > tmp.txt_$$

  if [ "${FILT}" = "i.MP9702" ]; then
    ACTUFILT="y"
  else  
    ACTUFILT=`echo ${FILT} | sed -e 's/\.MP.*//'`
  fi

  # if the images are given with the ending '.fits.fz' we change
  # it to '.fits':
  sed -e 's/\.fz//' tmp.txt_$$ > summary_images_${SURVEY}_${ACTUFILT}.txt
done

# now create the survey of available fields/filters:
sed -e 's/i.MP9702/y/' -e 's/\.MP.*//' ${INFOFILE} | awk '{print $1, $3}' |\
  sort -k1,1 | uniq > tmp.txt_$$

awk 'BEGIN {field = "dummy"; filters = ""} {
         if(field == "dummy") {field = $1}
         if ($1 == field) {
           filters = filters " " $2
         } else {
           sub(/^ /, "", filters); # the first line has a trailing space
                                   # in the filters variable; remove it
           printf("%-20s \"%s\"\n", field, filters);
           field = $1; filters = $2}
         }
         END {printf("%-20s \"%s\"\n", field, filters);}' tmp.txt_$$ > \
  ${SURVEY}_available_fields_filts.txt

rm tmp.txt_$$


