#!/bin/bash

# this script creates 8x8-binned mosaics for each image.
# The highly enhanced contrast enables one to easily detect
# satellite tracks and reflections from bright stars outside
# the field.
# Furthermore you can see how well the flat fielding worked.
#
# 15.10.2004:
# - I introduced a new command line argument for
#   the BITPIX value of the result image (can be 16 or -32).
#
# - temporaray files are put into the directory pointed
#   to by TEMPDIR
#
# 25.11.2004:
# I introduced a PREFIX for the images to be mosaiced.
# This allows better to select certain images in 
# a directory.
#
# 11.04.2005:
# I rewrote the script to use the 'album' program for
# image combining instead the FLIPS based immosaic_WFI

# $1: main directory
# $2: science directory
# $3: PREFIX for images to be mosaiced
# $4: extension (e.g. OFCSFF)
# $5: bin size
# $6: BITPIX for output image (16 or -32)

. MEGAPRIME.ini 

# set default for output BITPIX to 16:
if [ $# -lt 6 ]; then
  BITPIX=16
else
  BITPIX=$6
fi

cd $1/$2

if [ ! -d BINNED ]; then
  mkdir BINNED
fi

if [ -f ${TEMPDIR}/image_list_$$ ]; then
  rm ${TEMPDIR}/image_list_$$
fi

ls $3*_1$4.fits > ${TEMPDIR}/image_list_$$

cat ${TEMPDIR}/image_list_$$ |\
{
  while read file
  do
       BASE=`basename ${file} _1$4.fits`
       echo ${BASE}
       ${P_ALBUM} -l -p ${BITPIX} -b $5 9 4 \
                  ${BASE}_1$4.fits ${BASE}_2$4.fits\
                  ${BASE}_3$4.fits ${BASE}_4$4.fits ${BASE}_5$4.fits\
                  ${BASE}_6$4.fits ${BASE}_7$4.fits ${BASE}_8$4.fits ${BASE}_9$4.fits \
                  ${BASE}_10$4.fits ${BASE}_11$4.fits\
                  ${BASE}_12$4.fits ${BASE}_13$4.fits ${BASE}_14$4.fits\
                  ${BASE}_15$4.fits ${BASE}_16$4.fits ${BASE}_17$4.fits ${BASE}_18$4.fits \
                  ${BASE}_19$4.fits ${BASE}_20$4.fits\
                  ${BASE}_21$4.fits ${BASE}_22$4.fits ${BASE}_23$4.fits\
                  ${BASE}_24$4.fits ${BASE}_25$4.fits ${BASE}_26$4.fits ${BASE}_27$4.fits \
                  ${BASE}_28$4.fits ${BASE}_29$4.fits\
                  ${BASE}_30$4.fits ${BASE}_31$4.fits ${BASE}_32$4.fits\
                  ${BASE}_33$4.fits ${BASE}_34$4.fits ${BASE}_35$4.fits ${BASE}_36$4.fits \
                  > BINNED/${BASE}_mos.fits
  done
}

rm ${TEMPDIR}/image_list_$$
