#!/bin/bash

# this script runs the PHOTOMETRIX tool
# after astrometric calibration by ASTROMETRIX.
# This part only deal with relative photometry,
# not with the absolute one. Images are scales so that
# the mean of relative zeropoints for ALL input
# images is zero. The resulting fluxscale parameters
# are:
# f_i=exp(-0.4 zp[i])/t_i, where t_i is the exposure
# time.
# We assume that ALL chips of an exposure share the same
# photometric zeropoint, i.e. zeropint differences in
# different detectors are not taken into account.

# This is a very special version for processing CFHTLS
# Deep fields (see the file create_astrometrix_astrom_run_CFHTLS.sh)
# for further comments on why we split these scripts from
# the main track.

# 31.08.2007:
# The SExtractor executable is now called 'sex_theli'. I adapted
# the photometrix config file creation accordingly.
#
# 06.11.2007:
# catalogs were copied to the wrong directory and hence were
# all recreated! They have to go to the globphot subdirectory
# instead to the photom directory.

# $1: main dir.
# $2: science dir. (the cat dir is a subdirectory of this)
# $3: extension

. ${INSTRUMENT:?}.ini

DIR=`pwd`

cd /$1/$2/

if [ ! -d "photom" ]; then
  mkdir -p photom/globphot
fi

cd photom
# We (again) need to copy catalogues to satisfy the directory structure
# of the following PHOTOMETRIX call:
find /$1/$2/astrom/$2/ -name \[0\-9\]\*ldac -exec cp {} ./globphot \;

perl ${S_PHOTOMETRIX} -mkhead -mkcats\
 -s hdr_dir=/$1/$2/astrom/astglob -s fits_dir=/$1 \
 -s cats_dir=/$1/$2/astrom\
 -s list=/$1/$2/astrom/$2.list \
 -s MIN_OVERLAP=30 -s observatory=ESO\
 -s mcats_dir=/$1/$2/astrom/astglob -s ZP0=0. \
 -s SEX=sex_theli

# The previous PHOTOMETRIX call (again) copied catalogues in order
# to create new 'master catyalogues' (Those specify the overlap
# geometry between set exposures). The new copy is done to
# /$1/$2/photom and we can (re)move these files now:
${P_FIND} /$1/$2/photom/globphot -name M\*db \
          -exec mv {} /$1/$2/astrom/astglob \;
${P_FIND} /$1/$2/photom/globphot -name M\*ldac \
          -exec mv {} /$1/$2/astrom/astglob \;
${P_FIND} /$1/$2/photom/globphot -name index.db \
          -exec mv {} /$1/$2/astrom/astglob \;
${P_FIND} /$1/$2/photom/ -name \*ldac -exec rm {} \;

perl ${S_PHOTOMETRIX}  -calc

cd ..

# finally copy the photometrix headers to the right place
# and rename them. Here, we overwrite headers previously created
# by ASTROMETRIX. The old headers we copy to a directory
# astrometrix_copy if this directory does not yet already
# exist.

if [ ! -d "headers" ]; then
  mkdir headers
fi

cd ./headers

if [ ! -d "astrometrix_copy" ]; then
  mkdir astrometrix_copy
  ${P_FIND} .  -maxdepth 1 -name \*.head -exec mv {} ./astrometrix_copy \;
fi

${P_FIND} ../photom/globphot/ -name \*head -exec cp {} . \;

${P_FIND} . -name \*_1$3.head > files_$$

while read file
do
  i=1
  BASE=`basename ${file} _1$3.head`
  while [ "${i}" -le "${NCHIPS}" ]
  do
    mv ${BASE}_${i}$3.head ${BASE}_${i}.head
    i=$(( $i + 1 )) 
  done
done < files_$$

rm files_$$

cd ${DIR}

