#!/bin/bash

# script to identify and to move 'bad' images in the CARS/CFHTLS-Wide
# survey. Bad images are identified here via stellar ellipticity
# and relative zeropoint. This script is to consider all catalogues
# from a p0atch simultaneously! The required directory structure
# is described in the script 'so_scamp_wide.sh'. Identified, bad
# images are moves to directories with names .../W1/r/cat/BAD etc.
# The identified exposures are also listed in a file .../W1/r/badima_r.txt.
# Note that you need to mark identified BAD images in the survey catalogue
# to ensure a consistent processing lateron.

#$1: main directory; below are directoreis W1-W4!
#$2: field name (W1-W4)
#$3: filters to consider

MD=$1
FIELD=$2
FILTERS="$3"


# get list of problematic images; for the moment criteria
# to reject images are:
#
# - e1, e2 ellipticity components have a modulus larger than 0.15
# - relative zeropooint: < -0.2 or > 0.8

ELLIPLOW=-0.15
ELLIPHIGH=0.15
RELZPLOW=-0.2
RELZPHIGH=0.8

for FILTER in ${FILTERS}
do
  ldactoasc -i ${MD}/${FIELD}/${FILTER}/cat/chips.cat6 -t STATS \
                -s -b -k IMAGENAME e1 e2 RZP|\
        awk '$2 < '${ELLIPLOW}' || $2 > '${ELLIPHIGH}' ||\
             $3 < '${ELLIPLOW}' || $3 > '${ELLIPHIGH}' ||\
             $4 < '${RELZPLOW}' || $4 > '${RELZPHIGH}' {print $1}' > \
          ${MD}/${FIELD}/${FILTER}/badima_${FILTER}.asc
  
  DIR=`pwd`
  cd ${MD}/${SUBFIELD}/${FILTER}/cat
  test -d BAD || mkdir BAD
  while read CAT
  do
    mv ${CAT}* ./BAD
  done < ${MD}/${FIELD}/${FILTER}/badima_${FILTER}.asc  
    
  cd ${DIR}
  done
done

