#!/bin/bash -xv

# this script performs resampling of data with swarp
# preparing the final coaddition. It can perform
# its task in parallel mode.
#
# This special version for CFHTLS data creates its results
# in the coadd directory itself and does not follow
# possible limks!


# 08.06.2006
# The file 'coadd.head' is no longer removed at the end
# of the processing. If being unlucky it is needed by another
# process exactly at the moment when it is removed by this 
# script. It does not matter if it is not removed anyway.

# 21.03.2007:
# I included a test to check whether chips need to be co-added 
# at all. This cleanly treats cases where only individual chips
# of a mosaic should be co-added.

#$1: main dir.
#$2: science dir.
#$3: image extension (ext) on ..._iext.fits (i is the chip number)
#$4: coaddition identifier (4 char)
#$5: location of the global coadd.head file

# preliminary work:
. ${INSTRUMENT:?}.ini

# construct a unique name for the coadd.head file
# of this co-addition:
#
# The following 'sed' ensures a 'unique' construction with the
# '/' character which can appear in arbitrary combinations in
# file- and pathnames.
TMPNAME_1=`echo ${1##/*/} | sed -e 's!/\{2,\}!/!g' -e 's!^/*!!' -e 's!/*$!!'`
TMPNAME_2=`echo ${2} | sed -e 's!/\{2,\}!/!g' -e 's!^/*!!' -e 's!/*$!!'`
COADDFILENAME=${TMPNAME_1}_${TMPNAME_2}_${4}

for CHIP in $6
do
  RESULTDIR[${CHIP}]="/$1/$2/coadd_$4"      
done

for CHIP in $6
do
  FILES=`${P_FIND} $1/$2/coadd_$4/ -maxdepth 1 -name \*_${CHIP}$3.fits`
  # test whether we have something to do at all! In case that only individual
  # chips need to be co-added it may be that the preceeding 'ls' command returns
  # an empty list.

  if [ -n "${FILES}" ]; then
      DIR=`pwd`
      cd ${RESULTDIR[${CHIP}]}
    
      if [ ! -f coadd.head ]; then
        cp $5/coadd_${COADDFILENAME}.head ./coadd.head
      fi
    
      ${P_SWARP} -c ${DATACONF}/create_coadd_swarp.swarp \
                 ${FILES} -RESAMPLE Y -COMBINE N \
                 -RESAMPLE_SUFFIX .$4.resamp.fits \
                 -RESAMPLE_DIR . \
                 -NTHREADS 1 -VERBOSE_TYPE QUIET
      cd ${DIR}
  fi
done  
